@@ -10,6 +10,8 @@ from qds_ops.tparty.knife import Knife
 from qds_ops.entities.rds import RDS
 
 import requests
+import logging
+
 
 class Scheduler(Tier):
     tier = "scheduler"
@@ -69,7 +71,7 @@ class Scheduler(Tier):
     def create(self, args):
         knife = Knife()
         creds = knife.get_credentials(args.environment)
-        rows = RDS.run_query(args, "select value from rstore.settings where var='hadoop.keyname'")
+        rows = RDS.run_query(args.environment, args.tunnel, "select value from rstore.settings where var='hadoop.keyname'")
 
         #open the UDF
         base_path = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
@@ -122,6 +124,7 @@ class Scheduler(Tier):
         # TODO Use cname
         hostname = mc[0]
         url = "http://%s:9090/admin/pauseAll" % hostname
+        logging.debug(url)
         r = requests.put(url)
         self.print_response(r)
 
@@ -131,6 +134,7 @@ class Scheduler(Tier):
         # TODO Use cname
         hostname = mc[0]
         url = "http://%s:9090/admin/resumeAll" % hostname
+        logging.debug(url)
         r = requests.put(url)
         self.print_response(r)
 
@@ -140,7 +144,7 @@ class Scheduler(Tier):
         # TODO Use cname
         hostname = mc[0]
         url = "http://%s:9090/admin/checkAll" % hostname
-        print url
+        logging.debug(url)
         r = requests.get(url)
         self.print_response(r)
 
